.. linkGrabber documentation master file, created by
   sphinx-quickstart on Wed Jun 25 12:04:28 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to linkGrabber's documentation!
=======================================

Contents:

.. toctree::
   :maxdepth: 2

   install
   tutorial
   api_reference
   upcoming
   changes
   authors


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

